summaryrefslogtreecommitdiff
path: root/TAO/orbsvcs/orbsvcs/LB_GenericFactory.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'TAO/orbsvcs/orbsvcs/LB_GenericFactory.cpp')
-rw-r--r--TAO/orbsvcs/orbsvcs/LB_GenericFactory.cpp6
1 files changed, 4 insertions, 2 deletions
diff --git a/TAO/orbsvcs/orbsvcs/LB_GenericFactory.cpp b/TAO/orbsvcs/orbsvcs/LB_GenericFactory.cpp
index aa21aff170f..87c93109a22 100644
--- a/TAO/orbsvcs/orbsvcs/LB_GenericFactory.cpp
+++ b/TAO/orbsvcs/orbsvcs/LB_GenericFactory.cpp
@@ -348,8 +348,10 @@ TAO_LB_GenericFactory::populate_object_group (
replica_info->location_entry = location_entry;
- // No longer need to protect the allocated Replica_Map.
- safe_replica_info.release ();
+ // No longer need to protect the allocated Replica_Info or the
+ // Location map entry.
+ (void) safe_replica_info.release ();
+ (void) safe_location_entry.release ();
}
}